Authors: Idris Wardere, Jeremy Li

# What is square-learn?

**square-learn** is a machine learning library in Python built using NumPy and pandas. This library provides tools for data processing as well as trainable regression and classification models.

# Purpose

The reason we started this project was to gain a better understanding of how machines learn. We realized that the best way to understand this was to make our very own machine learning library. This idea of "learning to learn" is actually what inspired the name of the project (learning<sup>2</sup>)!

# Development

We use a Github Project to help keep track of the development of the library. This project can be accessed using [this link](https://github.com/users/idriswardere/projects/1) or in the Projects tab of this repository.

# Usage

Each of our classes and functions have docstrings that can be referenced to find out how they can be used. You can also check out `demos.py` to see examples of our models & utilities being used.
